@@ -7,15 +7,16 @@
    Website: http://www.garagejam.org/
  
  */
- 
- #include <gst/gst.h>
- #include <gtk/gtk.h>
- #include <glib/gstdio.h>
- #include <glib/gi18n.h>
 
-GtkWidget *line (gint jack, gchar *label) {
+#include <gst/gst.h>
+#include <gtk/gtk.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n.h>
+
+GtkWidget *line(gint jack, gchar *label)
+{
 	GtkWidget *window;
-	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title (GTK_WINDOW (window), label);
+	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title(GTK_WINDOW(window), label);
 	return (window);
 }
