@@ -16,8 +16,6 @@
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
-#include <champlain/champlain.h>
-#include <champlain-gtk/champlain-gtk.h>
 #include <string.h>
 #include <glib.h>
 #include <sys/socket.h>
@@ -280,7 +278,7 @@ static void gb_assistant_button_clicked(GtkButton *button,
 				GST_TAG_TITLE, g_get_real_name(),
 				GST_TAG_ARTIST, g_get_real_name(),
 				GST_TAG_ALBUM, "Voicegram",
-				GST_TAG_COMMENT, "GarageJam 4.0.0",
+				GST_TAG_COMMENT, "GarageJam 5.0.0",
 				GST_TAG_DATE,
 				g_date_time_format_iso8601(datestamp),
 				NULL);
